pyxmpp2.transport.WriteData

Package pyxmpp2 :: Module transport :: Class WriteData |
[hide private]

# Class WriteData

Data queued for write.

Instance Methods | [hide private]
__init__(self, data) x.__init__(...) initializes x; see help(type(x)) for signature |
__repr__(self) repr(x) |
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, data) (Constructor) |
x.__init__(...) initializes x; see help(type(x)) for signature Overrides: object.__init__ (inherited documentation)

### __repr__(self) (Representation operator) |
repr(x) Overrides: object.__repr__ (inherited documentation)